### This is a file where to store generated passwords with details

In fact they will be two files generated, the first as markdown  
and the second one as an SQLite database, which respectively are :   
passwords.md and passwords.db  

- **Example Password inside the markdown**  
  | Keys                   | Values           |
  |------------------------|------------------|
  | Date of Creation       | 09-20-2024 17:22 |
  | Description            | An example of password |
  | Strength               | Very Weak        |
  | Author                 | Hatix Ntsoa      |
  
  ```markdown
  password
  ```